@@ -368,17 +368,8 @@ std::string_view ltrim(const std::string_view s, const char &c)
 
 std::string &rtrim(std::string &s, const char &c)
 {
-    size_t pos = s.find_last_of(c);
-    size_t last = pos == string::npos ? s.length() : pos;
-    if (last + 1 < s.length())
-    {
-        if (s.at(last + 1) != c)
-        {
-            last = s.length();
-        }
-    }
-
-    s = s.substr(0, last);
+    size_t pos = s.find_last_not_of(c);
+    s.resize(pos == std::string::npos ? 0 : pos + 1);
     return s;
 }
 
@@ -863,6 +854,38 @@ void printPercentageLineCerr(const char *title, long long completed, long long t
     }
 }
 
+std::string wrapText(const std::string &input, std::size_t maxWidth, int indentSpaces)
+{
+    const std::string indent(indentSpaces, ' ');
+    std::istringstream iss(input);
+    std::ostringstream oss;
+    std::string word, line = indent;
+
+    while (iss >> word)
+    {
+        if (line.size() + word.size() + 1 > maxWidth)
+        {
+            oss << line << '\n';
+            line = indent + word;
+        }
+        else
+        {
+            if (line != indent)
+            {
+                line += ' ';
+            }
+            line += word;
+        }
+    }
+    if (!line.empty())
+    {
+        oss << line;
+    }
+
+    return oss.str();
+}
+
+
 int getFlag(const map<string, int> *flags, const char * optname)
 {
     auto i = flags->find(optname);
@@ -1661,5 +1684,6 @@ std::string getOrCreateSocketPath(bool createDirectory)
 
     return (socketFolder / sockname).string();
 }
+
 #endif // ifdef(_WIN32) else
 } //end namespace
