@@ -27,6 +27,8 @@ namespace SyncCommand
     std::unique_ptr<mega::MegaSync> getSync(mega::MegaApi& api, const std::string& pathOrId);
     std::unique_ptr<mega::MegaSync> reloadSync(mega::MegaApi& api, std::unique_ptr<mega::MegaSync>&& sync);
 
+    bool isAnySyncUploadDelayed(mega::MegaApi& api);
+
     void printSync(mega::MegaApi& api, ColumnDisplayer& cd, bool showHandle, mega::MegaSync& sync,  const SyncIssueList& syncIssues);
     void printSyncList(mega::MegaApi& api, ColumnDisplayer& cd, bool showHandles, const mega::MegaSyncList& syncList, const SyncIssueList& syncIssues);
 
@@ -41,3 +43,31 @@ namespace SyncCommand
 
     void modifySync(mega::MegaApi& api, mega::MegaSync& sync, ModifyOpts opts);
 }
+
+namespace GlobalSyncConfig
+{
+    void loadFromConfigurationManager(mega::MegaApi& api);
+
+    namespace DelayedUploads
+    {
+        struct Config
+        {
+            int mWaitSecs = 0;
+            int mMaxAttempts = 0;
+        };
+        std::optional<Config> getCurrentConfig(mega::MegaApi& api);
+
+        struct Limits
+        {
+            Config mLower;
+            Config mUpper;
+
+            bool isWaitSecsValid(int waitSecs) const;
+            bool isMaxAttemptsValid(int maxAttempts) const;
+        };
+        std::optional<Limits> getCurrentLimits(mega::MegaApi& api);
+
+        void updateWaitSecs(mega::MegaApi& api, int waitSecs);
+        void updateMaxAttempts(mega::MegaApi& api, int waitSecs);
+    }
+}
