@@ -267,7 +267,7 @@ int64_t mega_size(const char *path)
 string UpdateTask::getAppDataDir()
 {
     auto dirs = megacmd::PlatformDirectories::getPlatformSpecificDirectories();
-    return dirs->configDirPath();
+    return dirs->configDirPath().string();
 }
 
 #define MEGA_TO_NATIVE_SEPARATORS(x) std::replace(x.begin(), x.end(), '\\', '/');
@@ -878,7 +878,7 @@ bool UpdateTask::performUpdate()
 void UpdateTask::rollbackUpdate(size_t fileNum)
 {
     LOG(LOG_LEVEL_INFO, "Uninstalling update...");
-    for (size_t i = fileNum; i >= 0; i--)
+    for (int i = fileNum; i >= 0; i--)
     {
         string origFile = appFolder + localPaths[i];
         mega_rename(origFile.c_str(), (updateFolder + localPaths[i]).c_str());
