@@ -137,6 +137,9 @@ class MEGAcmdRmTest(unittest.TestCase):
         if not VERBOSE:
             clean_all()
 
+    def setUp(self):
+        print(f"\n=== Running test: {self._testMethodName} ===")
+
     def compare_and_clear(self):
         def cleanup():
             clear_local_and_remote()
