@@ -149,6 +149,9 @@ class MEGAcmdServingTest(unittest.TestCase):
         if not VERBOSE:
             clean_all()
 
+    def setUp(self):
+        print(f"\n=== Running test: {self._testMethodName} ===")
+
     def compare_find(self, what, localFindPrefix='localUPs'):
         if not isinstance(what, list):
             what = [what]
